function Add-KempLBRealServer {
    <#
    .Synopsis
        Adds a real server to LoadMaster
    .Description
        Adds a real server definition to a Kemp LoadMaster
    .Example
        Add-KempLBVirtualService -IP 1.2.3.4 -Protocol tcp -Port 80 | Add-KempLBRealServer -Rs 1.2.3.4 -Rsport 81
    .Link
        Add-KempLBRSOption
    #>
    [OutputType([PSObject])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,
    # The IP address of the real server
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [string]
    $Rs,
    # The port of the real server
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [string]
    $Rsport,
    # Options for the real server.  To explore potential options, use New-KempLBRSOption
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [PSObject]
    $RSOptions,

    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )
    process {
        #region
        Invoke-KempLoadMaster "addrs" -Parameter  @{
            VS = $ip
            Port = $port
            Prot = $protocol
            RS = $rs
            RSPort = $rsport
        } -InputObject $RSOptions -AsXml:$AsXML -AsTypeName KempLBVS
        #endregion
    }
}
