function Add-KempLBRuleToRS {
    <#
    .Synopsis
        Adds a Kemp rule to a Real Server
    .Description
        Adds a Kemp Load balancing rule to a real server
    .Example
        Add-KempLBRuleToRS -IP 1.2.3.4
    .Link
        Add-KempLBRealServer
    #>

    [OutputType([PSObject])]
    param(
    # The IP address of the Virtual Service
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    $IP,
    # The Port of the Virtual Service
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    $Port,
    # The Protocol of the Virtual Service    
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    $Protocol,
    #The IP of the Real Service
    $Rs,
    #The Port of the Real Service    
    $Rsport,
    #The name of the rule
    [string]$RuleName,
    #Addtional options to be applied to the Real Server
    $RSOptions,
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    process {
        #region
        Invoke-KempLoadMaster "addrsrule" -Parameter  @{
            VS = $IP
            Port = $Port
            Prot = $Protocol
            RS = $Rs
            RSPort = $Rsport
            Rule = $RuleName
        } -InputObject $RSOptions -AsXml:$AsXML -AsTypeName KempLBVS
        #endregion
    }
}