function Add-KempLBRuleToVS {
    <#
    .Synopsis
        Adds a Kemp rule to a Virtual Service
    .Description
        Adds a Kemp Load balancing rule to a virtual service        
    .Example
        New-KempLBRule xrule1 pattern
        $vs = Add-KempLBVirtualService -IP 1.2.3.4 -port 80 -protocol tcp
        $vs | Add-KempLBRuleToVS xrule1 

    .Link
        Add-KempLBVirtualService
    #>
    [OutputType([PSObject])]
    param(
    # Name of the VS Rule
    [string[]]$RuleName,
    # Name of the VS Rule
    [ValidateSet('pre','response','request')]
    [string[]]$RuleTypes='pre',
    # The IP address of the Virtual Service
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    $IP,
    # The Port address of the Virtual Service        
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    $Port,
    # The Protocol address of the Virtual Service
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    $Protocol,
        
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )
    Begin {
        $map = @{
            "pre"="addprerule"
            "response"="addresponserule"
            "request"="addrequestrule"
        }
    }

    Process {
        #region
        foreach ($rn in $RuleName)
        {            
            foreach ($RuleType in $RuleTypes)
            {                
                Invoke-KempLoadMaster $map.$RuleType -Parameter  @{
                    VS = $IP
                    Port = $Port
                    Prot = $Protocol
                    Rule = $rn
                } -AsXml:$AsXML 
            }
        }
        #endregion
    }
}