function Add-KempLBVirtualService {
    <#
    .Synopsis
        Add a new Virtual Service
    .Description
        Add a new Virtual Service to the Kemp LoadMaster
    .Example
        Add-KempLBVirtualService -ip 192.168.0.17 -port 80 -protocol tcp
    .Link
        Add-KempLBVSOption
    #>
    [OutputType([PSObject])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,

    #Sets advanced options for the Virtual Session
    $VSOptions,

    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {




        #region
        Invoke-KempLoadMaster "addvs" -Parameter  @{
            VS = $ip
            Port = $port
            Prot = $protocol
        } -InputObject $VSOptions -AsXml:$AsXML -AsTypeName KempLBVS
        #endregion
    }
}