Import-Module EZOut

$moduleName = 'KempLB'
$ModuleRoot = "c:\Kemp"

Write-TypeView -TypeName 'KempLBVS' -ScriptProperty @{
    ScheduleFullName = {
        switch ($this.Schedule) {
            "rr"       {"round robin"}
            "wrr"      {"weighted round robin"}
            "lc"       {"least connection"}
            "wlc"      {"weighted least connection"}
            "fixed"    {"fixed weighting"}
            "adaptive" {"resource based (adaptive)"}
            "sh"       {"source IP hash"}
            default    {$_}
        }
    }

    ServiceType = {
        switch ($this.VSType) {
            "gen"   {"Generic"}
            "http"  {"HTTP/HTTPS"}
            "tls"   {"STARTTLS protocols"}
            "ts"    {"Remote Terminal"}
            default {$_}
        }
    }

    HealthCheckType = {
        switch ($this.CheckType) {
            "icmp"   {"ICMP Ping"}
            "http"   {"HTTP Protocol"}
            "https"  {"HTTPS Protocol"}
            "tcp"    {"TCP Connection Only"}
            "smtp"   {"Mail (SMTP) Protocol"}
            "nntp"   {"Network News (NNTP) Protocol"}
            "ftp"    {"File Transfer (FTP) Protocol"}
            "telnet" {"Telnet Protocol"}
            "pop3"   {"Mailbox (POP3) Protocol"}
            "imap"   {"Mailbox (IMAP) Protocol"}
            "none"   {"None"}
            default {$_}
        }
    }

    Accelerate = {
        if(!$this.SSLAcceleration) {
            "N"
        } else {
            $this.SSLAcceleration
        }
    }

    Reencrypt = {$this.SSLReencrypt}

    PersistOption = {
        switch ($this.Persist) {
            "ssl"             {$_}
            "cookie"          {"Server Cookie"}
            "active-cookie"   {"Active Cookie"}
            "cookie-src"      {"Server cookie or Source IP"}
            "active-cook-src" {"Active Cookie or Source IP"}
            "cookie-hash"     {"Hash all Cookies"}
            "cookie-hash-src" {"Hash all Cookies or Source IP"}
            "url"             {"URL Hash"}
            "query-hash"      {"Hash of HTTP Query Item"}
            "host"            {"HTTP Host Header"}
            "header"          {"Selected Header"}
            "super"           {"Super Http"}
            "super-src"       {"Super HTTP and Source IP"}
            "src"             {$_}
            "rdp"             {$_}
            "rdp-src"         {$_}
            "rdp-sb"          {$_}
            "rdp-sb-drc"      {$_}
            default           {$_}
        }
    }

    RealServer = {
        if($this.RS) {
            foreach($realServer in @($this.RS)) {
                New-Object PSObject -Property @{Addr=$realServer.Addr; Port=$realServer.Port}
            }
        }
    }

    ServiceName = { $this.NickName }

} | Out-TypeData |
    Set-content "$moduleRoot\$ModuleName.Types.ps1xml"

$Properties = Echo ServiceName ServiceType Transparent VSAddress `
    VSPort Protocol ScheduleFullName Accelerate `
    Reencrypt PersistOption HealthCheckType RealServer 

Write-FormatView -TypeName 'KempLBVS' -Property $Properties -Wrap |
    Out-FormatData |
    Set-content "$moduleRoot\$ModuleName.Format.ps1xml"