function Get-KempLBRealServer {
    <#
    .Synopsis
        Lists all Real Servers on the LoadMaster
    .Description
        lists all Real Servers on a Kemp LoadMaster
    .Example
        Get-KempLBRealServer
    .Link
        Add-KempLBRealServer
    .Link
        Remove-KempLBRealServer    
    .Link
        Update-KempLBRealServer
    #>
    [OutputType([PSObject])]
    param(
    
    # Specifies an IP address, or a wildcard of an IP Address
    [string]$Address,

    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    process {
        #region Invoke REST Api

        $virtualServices = Invoke-KempLoadMaster "listvs" -asXml:$asXml -Parameter $parameters -DataPath "Response", "Success", "Data", "VS" -ASTypeName KempLBVS 
        
        $(
            foreach ($vs in $virtualServices)
            {
                if($vs.RealServer) {
                    foreach ($rs in @($vs.RealServer))
                    {                
                        [PSCustomObject][Ordered]@{
                            VSAddress = $vs.VSAddress
                            VSPort= $vs.VSPort
                            ComputerName=$rs.Addr
                            Port=$rs.Port
                        }
                    }
                }
            }
        ) | 
            Where {$_.Addr -like $address}

        #endregion Invoke REST Api
    }
}