function Get-KempLBRule {
    <#
    .Synopsis
        Gets Kemp LoadMaster rules
    .Description
        Gets rules registered on a Kemp LoadMaster
    .Example
        Get-KempLBRule
    .Example
        Get-KempLBRule "MyRule"
    .Link
        New-KempLBRule
    .Link
        Remove-KempLBRule
    #>
    [OutputType([PSObject], [xml])]
    param(
    # The name of the LoadMaster rule
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [String]$Name,
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    process {
    
        #region Execute REST API
        Invoke-KempLoadMaster "showrule" -asXml:$asXml -DataPath "Response", "Success", "Data", "MatchContentRule"  |
            Where {$_.Name -match $Name}
        #endregion Execute REST API
    }
    <#
    $uri=Get-KempLBUri "showrule"

    $r = Send-KempLBMessage $uri

    if($AsXML) { return $r}

    $xml=[xml]$r

    if($xml.Response.stat -eq 200) {
        $xml.Response.Success.Data.MatchContentRule |
            Where {$_.Name -match $Name}
    } else {
        $xml.Response.Error
    }#>
}