function Add-Kemp.LBVIP
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.AddLBVIP")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBVIP])]    
    PARAM (
        [CmdletBinding()]

        [Parameter(Mandatory=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBConnection] $Connection,

        [Parameter(Mandatory=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBVIP] $VIP
    )
    

    
    Add-KempLoadmaster -Port $Connection.DevicePort -IP $Connection.DeviceName -Credential $Connection.Credential
    Use-KempLoadMaster -IP $Connection.DeviceName |Out-null    
    

    $protocol = Get-Protocol | ? { $_.SericeName -eq $vip.Protocol.Name -or $_.Aliases -contains $vip.Protocol.Name }  |Select-Object -First 1 

    $protocol = if ($protocol) {
        $protocol.Protocol
    } else {
        "tcp"
    }

    $optionsParams = @{}

    if ($VIP.Persistence.Name) {
        if ($VIP.Persistence.Value) {
            if ($VIP.Persistence.Name.Contains("Cookie")) {
                $optionsParams.Cookie = $vip.Persistence.Value
            } 
            ElseIf ($VIP.Persistence.Name.Contains("Query")) {
                $optionsParams.QueryTag = $vip.Persistence.Value
            }
            ElseIf ($VIP.Persistence.Name.Contains("cookie")) {
                $optionsParams.Cookie = $vip.Persistence.Value
            }
        }

        $optionsParams.Persist = $vip.Persistence.Name
    }

    $vsParams = @{
        IP=$VIP.IPAddress 
        Port=$VIP.Port 
        Protocol=$protocol
        VSOptions = New-KempLBVSOption -Schedule $VIP.LoadBalancingMethod.Name -Nickname $VIP.Name @optionsParams
    }
    
    $virtualService = Add-KempLBVirtualService @vsParams 

    foreach ($m in @($vip.Member)) {
        Add-KempLBRealServer -IP $vip.IPAddress -Port $vip.port -Protocol $protocol -rs $m.Address -Rsport $m.Port | Out-Null        
    }

    $VIP
}
