function Get-Kemp.LBKnownVIP
{
    [Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownVIP")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBVIP])]
    PARAM (
        [CmdletBinding()]

        [Parameter(Mandatory=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBConnection] $Connection,

        [Parameter(Mandatory=$false)]
        [string] $Name
    )
    
    #Write-VMMMessage $MyInvocation.MyCommand.Name ""
    Add-KempLoadmaster -Port $Connection.DevicePort -IP $Connection.DeviceName -Credential $Connection.Credential
    Use-KempLoadMaster -IP $Connection.DeviceName | Out-Null

    $kempvips = Get-KempLBVirtualService

    foreach ($kVip in $kempvips) {
        if ($PSBoundParameters.Name -and ($kVip.NickName -ne $Name)) {
            continue
        }
        $lbVip = @{
            Name = $kVip.NickName
            IPAddress = $kVip.VSAddress
            Port = $kVip.VSPort
            Protocol = 
                New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBProtocol -Property @{
                    Name= $kVip.Protocol
                }
            LoadBalancingMethod = New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{
                Name = $kvip.ScheduleFullName
                Value = $kvip.Schedule
            }
                        
        }

        if ($kvip.PersistOption) {
            $lbVip.Persistence = New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBPersistence -Property @{
                Name = $kvip.PersistOption
                Value = $kvip.Persist
            }            
        }

        

        if ($kvip.RS) {
            $lbVip.Member = foreach ($rs in $kvip.rs) {
                
                New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBVIPMember -Property @{
                    Address = $rs.Addr
                    Port = $rs.Port
                }
                
            }
        }
                        
        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBVIP -Property $lbVip
    }    
} 
