function New-Kemp.LBConnection
{
    param(
    [Parameter(Position=0,Mandatory=$true)]
    [string]
    $DeviceName,

    [Parameter(Position=1,Mandatory=$true)]
    [uint32]
    $DevicePort,

    [Parameter(Position=2,Mandatory=$true)]
    [Management.Automation.PSCredential]
    $Credential

    )

    process {
        Add-KempLoadmaster -Port $DevicePort -IP $DeviceName -Credential $Credential
        Use-KempLoadMaster -IP $DeviceName |Out-null

        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBConnection -Property @{
            DeviceName = $DeviceName
            DevicePort = $DevicePort
            Credential = $Credential
        }
    }
}

function Open-Kemp.LBConnection
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.OpenLBConnection")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBConnection])]
    PARAM (
        [CmdletBinding()]

        [Parameter(Mandatory=$true, ValueFromPipeline=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBConnection] $Connection
    )


    Add-KempLoadmaster -Port $Connection.DevicePort -IP $Connection.DeviceName -Credential $Connection.Credential
    Use-KempLoadMaster -IP $Connection.DeviceName |Out-null
    
    Write-Output $Connection
}

function Close-Kemp.LBConnection
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.CloseLBConnection")]
    PARAM (
        [CmdletBinding()]

        [Parameter(Mandatory=$true, ValueFromPipeline=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBConnection] $Connection
    )

    $FunctionName=$MyInvocation.MyCommand.Name

   

    Write-Output $Connection
}

function Get-Kemp.LBKnownBalancingMethod
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownBalancingMethod")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod])]
    PARAM (
        [CmdletBinding()]
        [string] $Name
    )        
        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{
            Name  = "RoundRobin"
            Value = "rr"
        }
        
        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{
            Name  = "Weighted Round Robin"
            Value = "wrr"
        }

        
        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{        
            Name = "Least Connections"
            Value = "lc"
        }

        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{        
            Name = "Weighted Least Connection"
            Value = "wlc"
        }

        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{        
            Name = "Fixed Weighting"
            Value = "fixed"
        }

        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{        
            Name = "Resource based (adaptive)"
            Value = "adaptive"
        }

        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBBalancingMethod -Property @{        
            Name = "Source IP Hash"
            Value = "sh"
        }
        
}



function Get-Kemp.LBKnownPersistence
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownPersistence")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBPersistence])]
    PARAM (
        [CmdletBinding()]
        [string] $Name
    )

    $persistenceMap = @{
            "ssl"             = "ssl"
            "cookie"          ="Server Cookie"
            "active-cookie"   ="Active Cookie"
            "cookie-src"      ="Server cookie or Source IP"
            "active-cook-src" ="Active Cookie or Source IP"
            "cookie-hash"     ="Hash all Cookies"
            "cookie-hash-src" ="Hash all Cookies or Source IP"
            "url"             ="URL Hash"
            "query-hash"      ="Hash of HTTP Query Item"
            "host"            ="HTTP Host Header"
            "header"          ="Selected Header"
            "super"           ="Super Http"
            "super-src"       ="Super HTTP and Source IP"
            "src"             ="Source IP"
            "rdp"             ="rdp"
            "rdp-src"         ="rdp-src"
            "rdp-sb"          ="rdp-sb"
            "rdp-sb-src"      ="rdp-sb-src"
    }

    foreach ($kv in $persistenceMap.GetEnumerator()|sort key -descending) {
        New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBPersistence -Property @{
            Name = $kv.Value
            Value = $Kv.Key
        }
    }
}

function Get-Kemp.LBKnownProtocol
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownProtocol")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBProtocol])]
    PARAM (
        [CmdletBinding()]
        [string] $Name
    )

   
}

function Get-Kemp.LBKnownCertificate
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownCertificate")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBCertificate])]
    PARAM (
        [CmdletBinding()]
        [string] $Name
    )
   
}

function Get-Kemp.LBKnownMonitorProtocol
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownMonitorProtocol")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBMonitorProtocol])]
    PARAM (
        [CmdletBinding()]
        [string] $Name
    )
  
}

function Get-Kemp.LBKnownMonitor
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownMonitor")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBMonitor])]
    PARAM (
        [CmdletBinding()]
        [string] $Name
    )
    
}

function Get-Kemp.LBSystemInfo
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBSystemInfo")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBSystemInfo])]
    PARAM (
        [CmdletBinding()]

        [Parameter(Mandatory=$true, ValueFromPipeline=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBConnection] $Connection
    )

    Add-KempLoadmaster -Port $Connection.DevicePort -IP $Connection.DeviceName -Credential $Connection.Credential
    Use-KempLoadMaster -IP $Connection.DeviceName |Out-null    

    $si = New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBSystemInfo;
    $si.IPAddress = $Connection.DeviceName;
    $si.HostName = "$($Connection.DeviceName)";
    $si.Manufacturer = "Kemp";
    $si.Model = "LoadMaster";    
    $si.Version = (Get-KempLBVersion | Select-Object -ExpandProperty Version);

    Write-Output $si;
}



function Set-Kemp.LBVIPPersistence
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.SetLBVIPPersistence")]
    PARAM (
        [CmdletBinding()]

        [Parameter(Mandatory=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBConnection] $Connection,

        [Parameter(Mandatory=$true)]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBVIP] $Vip,

        [Parameter(Mandatory=$true)]
        [AllowNull()]
        [Microsoft.SystemCenter.DataCenterManager.LB.LBPersistence] $Persistence
    )

    
    $Vip.Persistence = $persistence;
} 


function Get-Kemp.LBKnownProtocol
{
    [System.Management.Instrumentation.ManagedNameAttribute("DataCenterManager.LB.RetrieveLBKnownProtocol")]
    [OutputType([Microsoft.SystemCenter.DataCenterManager.LB.LBProtocol])]
    PARAM (
        [CmdletBinding()]
        [string] $Name
    )

    New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBProtocol -Property @{Name="http"}
    New-Object Microsoft.SystemCenter.DataCenterManager.LB.LBProtocol -Property @{Name="https"}

}
