function New-KempLBRSOption {
    <#
    .Synopsis
        Used to update parameters on a Kemp Real Server
    .Description
        Used to update the parameters on a Kemp Real Server
    .Example
        New-KempLBRSOption -NewPort 100
    .Link
        Add-KempLBRealServer
    #>
    [OutputType([PSObject])]
    param(
    # The IP Address for the real server
    [Parameter(Position=0,ValueFromPipelineByPropertyName=$true)]
    [string]$RealServer,
    # The port used by the real server
    [Parameter(Position=1,ValueFromPipelineByPropertyName=$true)]
    [ValidateRange(3,65535)]
    [int]$RealServerPort,
    # If set, the option should be disabled
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$Disable,
    # The way the requests should be forwarded
    [Parameter(Position=2,ValueFromPipelineByPropertyName=$true)]
    [ValidateSet("nat","route")]
    [string]$Forward,
    # The limit of the request
    [Parameter(Position=3,ValueFromPipelineByPropertyName=$true)]
    [ValidateRange(0,100000)]
    [int64]$Limit,
    # The new port to use for the real server
    [Parameter(Position=4,ValueFromPipelineByPropertyName=$true)]
    [ValidateRange(3,65535)]
    [int]$NewPort,
    # The weight of the option
    [Parameter(Position=5,ValueFromPipelineByPropertyName=$true)]
    [ValidateRange(1,65535)]
    [int]$Weight
    )

    process {
        #region Generate the output object
        $null = $PSBoundParameters.Remove("Disable")
        $PSBoundParameters.Enable = -not $Disable
        [pscustomobject]([ordered]@{}+$PSBoundParameters)
        #endregion Generate the output object
    }
}
