function New-KempLBRule {
    <#
    .Synopsis
        Create and add a rule to the Kemp LoadMaster
    .Description
        Creates and adds a new rule to the Kemp LoadMaster
    .Example
        New-KempLBRule -Name rule1 -Pattern pattern1
    .Link
        Add-KempLBRuleToRS
    .Link
        Add-KempLBRuleToVS
    .Link
        Get-KempLBRule
    .Link
        Remove-KempLBRule
    .Link
        Remove-KempLBRuleFromRS
    .Link
        Update-KempLBRule
    #>

    [OutputType([PSObject])]
    param(
    # Name of the rule
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true,ValueFromPipeline=$true)]
    [string]$Name,
    # The rules pattern
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [string]$Pattern,
    # Type of rule
    [ValidateSet("regex","prefix","postfix")]
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [string]$MatchType = "regex",
    #If set, will include Host in URL
    [bool]$IncHost,
    #If set, will ignore case
    [bool]$NoCase,
    # Negation
    [bool]$Negate,
    #If set, will include Query in URL
    [bool]$IncQuery,        
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {

        #region Invoke REST Api
        [void]$PSBoundParameters.Remove("AsXml")

        $parameters = @{} + $PSBoundParameters

        try {
            Invoke-KempLoadMaster "addrule" -asXml:$asXml -Parameter $parameters -DataPath "Response", "Success", "Data", "MatchContentRule" 2>&1
        } catch {
            Write-Error $_
        }
        #endregion Invoke REST Api
    }
}