function New-KempLBVSOption {
    <#
    .Synopsis
        Used to update parameters on a Kemp Virtual Service
    .Description
        Used to update the parameters on a Kemp Virtual Service
    .Example
        New-KempLBVSOption -Nickname TestServer
    .Link
        Add-KempLBVirtualService
    #>
    [OutputType([PSObject])]
    param(
        # AddVia
        [Parameter(ValueFromPipeline=$true)]
        [ValidateRange(0,6)]
        [Int16]$AddVia,
        # Cache
        [bool]$Cache = $false,
        # Add Help
        [string]$CertFile,
        [ValidateSet("tcp","icmp","https","http","smtp","nntp","ftp","telnet","pop3","imap","rdp","none")]
        # Add Help
        [string]$CheckType = "tcp",
        # Add Help
        [string]$CheckHost,
        # Add Help
        [string]$CheckPattern,
        # Add Help
        [string]$CheckUrl,
        # Add Help
        [bool]$CheckUse1_1 = $false,
        [ValidateRange(3,65535)]
        # Add Help
        [Int32]$CheckPort,
        [ValidateRange(0,2)]
        # Add Help
        [Int16]$ClientCert = 0,
        # Add Help
        [bool]$Compress = $false,
        # Add Help
        [string]$Cookie,
        [ValidateRange(0,100)]
        # Add Help
        [Int16]$CachePercent = 0,
        # Add Help
        [string]$DefaultGateway,
        # Add Help
        [bool]$Enable = $true,
        [ValidateRange(300,550)]
        # Add Help
        [Int16]$ErrorCode = 0,
        # Add Help
        [string]$ErrorUrl,
        [ValidateRange(3,65530)]
        # Add Help
        [Int32]$PortFollow,
        # Add Help
        [bool]$ForceL7 = $true,
        [ValidateRange(0,86400)]
        # Add Help
        [Int32]$Idletime,
        # Add Help
        [String[]]$LocalBindAddresses,
        [ValidateSet("gen","http","tls","ts")]
        # Add Help
        [string]$VSType,
        # Add Help
        [string]$Nickname,
        [ValidateSet(
        'Active Cookie','Active Cookie or Source IP','active-cookie','active-cook-src','cookie',
        'cookie-hash','cookie-hash-src','cookie-src','Hash all Cookies',
        'Hash all Cookies or Source IP',
        'Hash of HTTP Query Item','header','host','HTTP Host Header',
        'query-hash','rdp','rdp-sb','rdp-sb-src','rdp-src',
        'Selected Header','Server Cookie','Server cookie or Source IP', 'Source IP', 
        'src','ssl','super','Super Http','SourceIP',
        'Super HTTP and Source IP','super-src','url','URL Hash'
        )]
        # Add Help
        [string]$Persist,
        [ValidateRange(0,86400)]
        # Add Help
        [Int32]$PersistTimeout,
        # Add Help
        [string]$QueryTag,
        # Add Help
        [bool]$SSLEncrypt,
        # Add Help
        [bool]$SSLReverse,
        [ValidateSet("","http","https")]
        # Add Help
        [string]$SSLRewrite,
        [ValidateSet("rr","wrr","lc","wlc","fixed","adaptive","sh","Least Connections","Round Robin","RoundRobin", "Weighted Least Connection", "Fixed Weighting", "Resource based (adaptive)", "Source IP Hash", "LeastConnections", "Weighted Round Robin")]
        # Add Help
        [string]$Schedule,
        [ValidateRange(0,5)]
        # Add Help
        [Int16]$ServerInit,
        # Add Help
        [bool]$SSLAcceleration,
        # Add Help
        [string]$StandByAddress,
        # Add Help
        [Int32]$TransactionLimit,
        # Add Help
        [bool]$Transparent,
        # Add Help
        [bool]$UseforSnat,
        # Add Help
        [bool]$CheckUseGet,
        [ValidateRange(0,7)]
        # Add Help
        [Int16]$Verify,
        # Add Help
        [string]$ExtraHdrKey,
        # Add Help
        [string]$ExtraHdrValue,
        # Add Help
        [string]$AllowedHosts,
        # Add Help
        [string]$AllowedDirectories,
        # Add Help
        [string]$Domain,
        # Add Help
        [string]$Logoff,
        [ValidateRange(0,7)]
        # Add Help
        [Int16]$ESPLogs,
        # Add Help
        [string]$SMTPAllowedDomains,
        # Add Help
        [bool]$ESPEnabled,
        [ValidateRange(0,4)]
        # Add Help
        [Int16]$InputAuthMode,
        [ValidateRange(0,2)]
        # Add Help
        [Int16]$OutputAuthMode,
        [ValidateRange(0,1)]
        # Add Help
        [Int16]$StartTLSMode,
        [ValidateRange(3,65535)]
        # Add Help
        [Int32]$ExtraPorts,
        # Add Help
        [string]$AltAddress,
        # Add Help
        [bool]$MultiConnect,
        # Add Help
        [string]$SingleSignOnDir
    )

    Process {
        $ScheduleMap = @{
            "Round Robin" = "rr"
            "RoundRobin" = "rr"
            "Weighted Round Robin" = "wrr"
            "WeightedRoundRobin" = "wrr"
            "Least Connections" = "lc"
            "LeastConnections" = "lc"
            "Weighted Least Connection" = "wlc"
            "WeightedLeastConnection" = "wlc"
            "Fixed Weighting" = "fixed"
            "FixedWeighting" = "fixed"
            "Resource based (adaptive)" = "adaptive"
            "Source IP Hash" = "sh"
        }

         $persistenceMap = @{
            "ssl" = "ssl"
            "Source IP" = "src"
            "SourceIP" = "src"
            "Server Cookie" = "cookie"
            "Active Cookie" = "active-cookie"
            "Server cookie or Source IP" = "cookie-src"
            "Active Cookie or Source IP" = "active-cook-src"
            "Hash all Cookies" = "cookie-hash"
            "Hash all Cookies or Source IP" = "cookie-hash-src"
            "URL Hash" = "url"
            "Hash of HTTP Query Item" = "query-hash"
            "HTTP Host Header" = "host"
            "Selected Header" = "header"
            "Super Http" = "super"
            "Super HTTP and Source IP" = "super-src"
            "src"="src"
            "rdp"="rdp"
            "rdp-src"="rdp-src"
            "rdp-sb" ="rdp-sb"
            "rdp-sb-src"="rdp-sb-src"
        }


        if ($PSBoundParameters.Schedule -and $scheduleMap[$PSBoundParameters.Schedule]) {
            $PSBoundParameters.Schedule = $scheduleMap[$PSBoundParameters.Schedule]
        }

        if ($PSBoundParameters.Persist -and $persistenceMap[$PSBoundParameters.Persist]) {
            $PSBoundParameters.Persist = $persistenceMap[$PSBoundParameters.Persist]
        }
        #region
        [pscustomobject]([ordered]@{}+$PSBoundParameters)
        #endregion
    }
}