function Remove-KempLBRealServer {
    <#
    .Synopsis
        Removes a real server from a Loadmaster
    .Description
        Removes a real server from a Kemp Loadmaster
    .Example
        Get-KempLBVirtualService | Remove-KempLBRealServer -Rs 1.2.3.4 -rsport 81
    .Link
        Add-KempLBRealServer
    .Link
        Disable-KempLBRealServer
    .Link
        Enable-KempLBRealServer
    .Link
        Show-KempLBRealServer
    .Link
        Update-KempLBRealServer    
    #>
    [CmdletBinding(SupportsShouldProcess=$true, ConfirmImpact='High')]
    [OutputType([Nullable])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server 
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,

    # The IP of the real server
    $Rs,
    # The Port of the real server
    $Rsport,        
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {
        if($PSCmdlet.ShouldProcess("$($rs):$($rsport)")) {
            #region Execute REST API
            Invoke-KempLoadMaster "delrs" -Parameter @{
                VS = $ip
                Port  = $port
                Prot = $protocol
                RS = $rs
                RSPort = $rsPort 
            } -AsXml:$AsXML 
            #endregion Execute REST API            
        }
    }
}