function Remove-KempLBRuleFromRS {
    <#
    .Synopsis
        Remove rule from Virtual Service
    .Description
        Remove a rule from a Virtual Service in the LoadMaster
    .Example
      Get-KempLBVirtualService | Remove-KempLBRuleFromRS -Rs 1.2.3.4 -Rsport 99 -Rule testrule
    .Link
        Add-KempLBRuleToRS
    .Link
        Add-KempLBRuleToVS
    .Link
        Get-KempLBRule
    .Link
        New-KempLBRule
    .Link
        Remove-KempLBRule
    .Link
        Update-KempLBRule
    #>
    
    [OutputType([Nullable])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server 
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,

    # The IP address of the real server
    [Parameter(ValueFromPipelineByPropertyName=$true)]    
    [string]
    $Rs,

    # The port on the real server
    [Parameter(ValueFromPipelineByPropertyName=$true)]    
    [int]
    $Rsport,
    # The name of the rule
    [Parameter(ValueFromPipelineByPropertyName=$true)]    
    [string]$Rule,
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    process {
        #region Execute REST API
        Invoke-KempLoadMaster "delrsrule" -Parameter  @{
            VS = $IP
            Port = $Port
            Prot = $Protocol
            RS = $Rs
            RSPort = $Rsport
            Rule = $Rule
        } -AsXml:$AsXML
        #endregion Execute REST API
    }   
}