function Remove-KempLBVirtualService {
    <#
    .Synopsis
        Delete a Virtual Service
    .Description
        Delete a Virtual Service from the LoadMaster
    .Example
        Get-KempLBVirtualService | Remove-KempLBVirtualService
    .Link
        Add-KempLBVirtualService
    .Link
        Get-KempLBVirtualService
    .Link
        Show-KempLBVirtualService
    .Link
        Update-KempLBVirtualService
    #>
    [CmdletBinding(SupportsShouldProcess=$true,ConfirmImpact='High')]
    [OutputType([Nullable])]
    param(
    # The IP Address to the virtual server
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server 
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,       
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {
        if($PSCmdlet.ShouldProcess("$($IP):$($Port)[$($Protocol)]")) {
            #region Invoke REST Api
            Invoke-KempLoadMaster "delvs" -Parameter @{
                VS = $IP
                Port = $Port
                Prot = $Protocol
            } -asXml:$asXml 
            #endregion Invoke REST Api
        }
    }
}