function Restart-KempLoadBalancer {
    <#
    .Synopsis
        Restarts a Kemp LoadMaster 
    .Description
        Restarts the Kemp LoadMaster 
    .Example
        Restart-KempLoadBalancer
    .Link
        KempLoadBalancer
    #>

    [OutputType([Nullable])]
    param(    
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML,
    # If set, will wait for the LoadBalancer to become available
    [Switch]$Wait
    )

    process {


    $canPing = (Test-Connection -ComputerName $script:ActieKempLoadMasterConnection.IP -Count 1  -ErrorAction SilentlyContinue) -as [bool]

    if ($canPing) {
        #region Execute REST API
        
        Invoke-KempLoadMaster "reboot" -AsXml:$AsXML 
        #endregion Execute REST API
    }


        if ($wait) {
            Start-Sleep -Seconds 1 
            $progId = Get-Random
            $n = 0
            do {
                Write-Progress "Waiting for LoadMaster to Reboot ($($script:ActieKempLoadMasterConnection.IP))" " " -PercentComplete $n -Id $progId
                $n+=5
                if ($n -gt 100) { $n = 0 } 
                $canPing = (Test-Connection -ComputerName $script:ActieKempLoadMasterConnection.IP -Count 1  -ErrorAction SilentlyContinue) -as [bool]
            
            } while (-not $canPing)
            Write-Progress "LoadMaster $($script:ActieKempLoadMasterConnection.IP) Rebooted" " " -Completed -Id $progId
        }

    }
    
   
}