function Show-KempLBRealServer {
    <#
    .Synopsis
        Show details of a real server
    .Description
        Show details of a real server in Kemp LoadMaster
    .Example
        Get-KempLBVirtualService | Show-KempLBRealServer -Rs $ip -Rsport 81
    .Link
        Add-KempLBRealServer
    .Link
        Disable-KempLBRealServer
    .Link
        Enable-KempLBRealServer
    .Link
        Remove-KempLBRealServer
    .Link
        Show-KempLBRealServer
    .Link
        Update-KempLBRealServer
    #>
    [OutputType([PSObject])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server 
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,
    # The IP address of the real server
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [string]
    $Rs,
    # The port of the real server
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [string]
    $Rsport,
    
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )
    process {

        #region
        Invoke-KempLoadMaster "showrs" -Parameter  @{
            vs= $IP
            port = $Port
            prot = $Protocol
            rs = $Rs
            RsPort = $Rsport
        } -AsXml:$AsXML -DataPath "Response", "Success", "Data", "RS"
        #endregion

    }
}