function Show-KempLBVirtualService {
    <#
    .Synopsis
        Display a Virtual Service
    .Description
        Display all Virtual Services defined in the LoadMaster
    .Example
        Show-KempLBVirtualService
    .Link
        Add-KempLBVirtualService
    .Link
        Get-KempLBVirtualService
    .Link
        Remove-KempLBVirtualService
    .Link
        Show-KempLBVirtualService
    .Link
        Update-KempLBVirtualService
    #>

    [OutputType([PSObject])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server 
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,

    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {
        #region Invoke REST Api
        Invoke-KempLoadMaster "showvs" -asXml:$asXml -Parameter @{
            IP = $ip
            Port = $port
            Protocol = $protocol
        } 
        #endregion Invoke REST Api
    }
}