function Update-KempLBRealServer {
    <#
    .Synopsis
        Updates a real server in LoadMaster
    .Description
        Updates a real server's definition in Kemp LoadMaster
    .Example
        $opt = New-KempLBRSOption -NewPort 99
        Get-KempLBVirtualService | Update-KempLBRealServer -Rs 1.2.3.4 -Rsport 88 -RSOptions $opt
    .Link
        Add-KempLBRealServer
    .Link
        Disable-KempLBRealServer
    .Link
        Enable-KempLBRealServer
    .Link
        Show-KempLBRealServer
    .Link
        Get-KempLBVirtualService
    #>
    [OutputType([PSObject])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    [string]
    $IP,
    # The port of the virtual server 
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    [int]
    $Port,

    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSProt")]
    [string]
    $Protocol,

    # The IP Address of the real server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [string]
    $Rs,

    # The port on the real server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [string]
    $Rsport,

    # The set of options for the real server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [PSObject]
    $RSOptions,        
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {
        #region Execute REST API
        Invoke-KempLoadMaster modrs -Parameter @{
            vs = $ip
            port = $port
            prot = $protocol
            rs = $rs
            rsport = $rsport
        } -InputObject $RSOptions
        #endregion Execute REST API        
    }
}