function Update-KempLBRule {
    <#
    .Synopsis
        Updates a rule on a Kemp LoadMaster
    .Description
        Updates a load balancer rule on a Kemp LoadMaster
    .Example
        Update-KempLBRule t1 -Pattern p3 -Negate $true
    .Link
        New-KempLBRule        
    #>

    [OutputType([PSObject])]
    param(
    # The name of the rule
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true,ValueFromPipeline=$true)]
    [string]$Name,
    # The rule pattern
    [Parameter(Mandatory=$true,ValueFromPipelineByPropertyName=$true)]
    [string]$Pattern,
    # The type of pattern.  By default, regex
    [ValidateSet("regex","prefix","postfix")]
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [string]$MatchType = "regex",
    # If set, will include the host
    [switch]$IncHost,
    # If set, will be case-insensitive
    [switch]$NoCase,
    # If set, the rule will be triggered when the condition is not met
    [switch]$Negate,
    # If set, will include the query string
    [switch]$IncQuery,        
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {
        #region Invoke REST Api
        [void]$PSBoundParameters.Remove("AsXml")

        $parameters = @{} + $PSBoundParameters

        Invoke-KempLoadMaster "modrule" -Parameter $parameters -AsXML:$AsXML
        #endregion Invoke REST Api
    }
}