function Update-KempLBServiceHealth {
    <#
    .Synopsis
        Updates the Service Health of a LoadMaster
    .Description
        Gets Service Health parameters from a Kemp LoadMaster
    .Example
        Update-KempLBServiceHealth
    .Link
        Get-KempLBServiceHealth
    #>

    [OutputType([PSObject])]
    param(
    # If set, updates the RetryInterval
    [Int16]
    [ValidateRange(9,120)]
    $RetryInterval,
    # If set, updates the Retry Count
    [Int16]
    $RetryCount,
    # If set, updates the Timeout
    [Int16]
    $Timeout,
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {
        #region Execute REST API                        
        [void]$PSBoundParameters.Remove("AsXml")
        $parameters = @{} + $PSBoundParameters
        Invoke-KempLoadMaster "modhealth" -Parameter $parameters -AsXML:$AsXML
        #endregion Execute REST API
    }
}