function Update-KempLBVirtualService {
    <#
    .Synopsis
        Modify a Virtual Service
    .Description
        Modify a Virtual Service in a Kemp LoadMaster
    .Example
        Get-KempLBVirtualService| Update-KempLBVirtualService -VSOptions (New-KempLBVSOption -Nickname TestServer)
    .Link
        Add-KempLBVirtualService
    .Link
        Get-KempLBVirtualService
    .Link
        Remove-KempLBVirtualService
    .Link
        Show-KempLBVirtualService
    #>
    [OutputType([PSObject], [xml])]
    param(
    # The IP Address to the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSAddress")]
    $IP,
    # The port of the virtual server 
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Alias("VSPort")]
    $Port,
    # The protocol of the virtual server
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    $Protocol,
    #Set advanced options fot the Virtual Service
    $VSOptions,
    # If set, XML will be directly returned from the REST API
    [Parameter(ValueFromPipelineByPropertyName=$true)]
    [Switch]$AsXML
    )

    Process {
        #region Invoke REST Api
        Invoke-KempLoadMaster -Command modvs -Parameter @{
            vs = $IP
            port = $Port
            prot = $Protocol
        } -InputObject $VSOptions -ASTypeName KempLBVS
        #endregion Invoke REST Api
    }
}