function Use-KempLoadMaster
{
	<#
		.Synopsis
				Uses a registered LoadMaster device
		.Description
				Uses a registered LoadMaster device.  

				All commands sent after this point will communicate with the KempLoadMaster
		.Example
				Use-KempLoadMaster -IP 172.20.0.171
		.Link
				Add-KempLoadMaster
		.Link
				Get-KempLoadMaster
		.Link
				Remove-KempLoadMaster   
	#>
	[OutputType([Nullable])]
	param(
		# The IP address of the LoadMaster
		[Parameter(Mandatory=$true,Position=0,ValueFromPipelineByPropertyName=$true)]
		[string]
		$IP
	)

	process {

		#region Get the details from the registry
		$fullRegistryPath = "HKCU:\Software\KEMP\KEMPLoadMaster\PowerShell\Connections\$IP"

		$EncryptedUserName = Get-ItemProperty -Path $fullRegistryPath -Name "EncryptedUserName" -ErrorAction SilentlyContinue | Select-Object -ExpandProperty EncryptedUserName
		$EncryptedPassword = Get-ItemProperty -Path $fullRegistryPath -Name "EncryptedPassword" -ErrorAction SilentlyContinue | Select-Object -ExpandProperty EncryptedPassword

		$convertedUserName  = (New-Object Management.Automation.PSCredential ' ', ($EncryptedUserName | ConvertTo-SecureString)).GetNetworkCredential().Password

		$Credential = (New-Object Management.Automation.PSCredential $convertedUserName, ($EncryptedPassword | ConvertTo-SecureString))

		if (-not $script:KempLoadMasterConnections) {
			$script:KempLoadMasterConnections = @{}
		}

		$script:KempLoadMasterConnections[$IP] = @{
			Credential = $Credential
			IP = $ip
			FriendlyName = Get-ItemProperty -Path $fullRegistryPath -Name FriendlyName -ErrorAction SilentlyContinue | Select-Object -ExpandProperty FriendlyName
			Port = Get-ItemProperty -Path $fullRegistryPath -Name Port -ErrorAction SilentlyContinue | Select-Object -ExpandProperty Port
		}

		$script:ActiveKempLoadMasterConnection = $script:KempLoadMasterConnections[$IP]
		#endregion Get the details from the registry

		Get-KempLoadMaster | Where-Object {$_.IP -eq $ip }

	}
}

